@@ -6,8 +6,8 @@ from types import GeneratorType
 
 from testfixtures import not_there
 from testfixtures.compat import (
-    ClassType, Unicode, basestring, mock_call, unittest_mock_call
-)
+    ClassType, Unicode, basestring, mock_call, unittest_mock_call,
+    PY3)
 from testfixtures.resolve import resolve
 from testfixtures.utils import indent
 
@@ -304,15 +304,22 @@ def compare_text(x, y, context):
     return message
 
 
+def compare_bytes(x, y, context):
+    if x == y:
+        return
+    labelled_x = context.label('x', repr(x))
+    labelled_y = context.label('y', repr(y))
+    return '\n%s\n!=\n%s' % (labelled_x, labelled_y)
+
+
 def compare_call(x, y, context):
     if x == y:
         return
     x_name, x_args, x_kw = x
     y_name, y_args, y_kw = y
-    context.different(x_name, y_name, ' function name')
-    context.different(x_args, y_args, ' args')
-    context.different(x_kw, y_kw, ' kw')
-    return 'mock.call not as expected:'
+    if x_name == y_name and x_args == y_args and x_kw == y_kw:
+        return compare_call(x.parent, y.parent, context)
+    return compare_text(repr(x), repr(y), context)
 
 
 def _short_repr(obj):
@@ -337,6 +344,9 @@ _registry = {
     BaseException: compare_exception,
     }
 
+if PY3:
+    _registry[bytes] = compare_bytes
+
 
 def register(type, comparer):
     """
@@ -406,10 +416,12 @@ class CompareContext(object):
             possible.append(actual)
 
         if len(possible) != 2:
-            raise TypeError(
-                'Exactly two objects needed, you supplied: ' +
-                repr(possible)
-            )
+            message = 'Exactly two objects needed, you supplied:'
+            if possible:
+                message += ' {}'.format(possible)
+            if self.options:
+                message += ' {}'.format(self.options)
+            raise TypeError(message)
 
         return possible
 
