@@ -4,6 +4,8 @@ import sys
 PY_VERSION = sys.version_info[:2]
 
 PY_36_PLUS = PY_VERSION >= (3, 6)
+PY_37_PLUS = PY_VERSION >= (3, 7)
+
 
 if PY_VERSION > (3, 0):
 
@@ -24,6 +26,7 @@ if PY_VERSION > (3, 0):
     from io import StringIO
     xrange = range
     from itertools import zip_longest
+    from functools import reduce
 
 else:
 
@@ -44,6 +47,7 @@ else:
     from StringIO import StringIO
     xrange = xrange
     from itertools import izip_longest as zip_longest
+    reduce = reduce
 
 try:
     from mock import call as mock_call
